@@ -8,13 +8,13 @@
 //  SS  SS   tt   ee      ll   ll  aa  aa
 //   SSSS     ttt  eeeee llll llll  aaaaa
 //
-// Copyright (c) 1995-2015 by Bradford W. Mott, Stephen Anthony
+// Copyright (c) 1995-2016 by Bradford W. Mott, Stephen Anthony
 // and the Stella Team
 //
 // See the file "License.txt" for information on usage and redistribution of
 // this file, and for a DISCLAIMER OF ALL WARRANTIES.
 //
-// $Id: EventHandlerSDL2.cxx 3131 2015-01-01 03:49:32Z stephena $
+// $Id: EventHandlerSDL2.cxx 3254 2016-01-23 18:16:09Z stephena $
 //============================================================================
 
 #include "OSystem.hxx"
@@ -26,11 +26,6 @@ EventHandlerSDL2::EventHandlerSDL2(OSystem& osystem)
 {
 }
 
-// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-EventHandlerSDL2::~EventHandlerSDL2()
-{
-}
-
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void EventHandlerSDL2::enableTextEvents(bool enable)
 {
@@ -40,12 +35,6 @@ void EventHandlerSDL2::enableTextEvents(bool enable)
     SDL_StopTextInput();
 }
 
-// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-const char* EventHandlerSDL2::nameForKey(StellaKey key) const
-{
-  return SDL_GetScancodeName(SDL_Scancode(key));
-}
-
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void EventHandlerSDL2::pollEvent()
 {
@@ -58,9 +47,9 @@ void EventHandlerSDL2::pollEvent()
       case SDL_KEYDOWN:
       {
         if(!myEvent.key.repeat)
-          handleKeyEvent((StellaKey)myEvent.key.keysym.scancode,
-                         (StellaMod)myEvent.key.keysym.mod,
-                          myEvent.key.type == SDL_KEYDOWN);
+          handleKeyEvent(StellaKey(myEvent.key.keysym.scancode),
+                         StellaMod(myEvent.key.keysym.mod),
+                         myEvent.key.type == SDL_KEYDOWN);
         break;
       }
 
@@ -113,7 +102,7 @@ void EventHandlerSDL2::pollEvent()
         handleJoyEvent(myEvent.jbutton.which, myEvent.jbutton.button,
                        myEvent.jbutton.state == SDL_PRESSED ? 1 : 0);
         break;
-      }  
+      }
 
       case SDL_JOYAXISMOTION:
       {
