@@ -8,13 +8,13 @@
 //  SS  SS   tt   ee      ll   ll  aa  aa
 //   SSSS     ttt  eeeee llll llll  aaaaa
 //
-// Copyright (c) 1995-2015 by Bradford W. Mott, Stephen Anthony
+// Copyright (c) 1995-2016 by Bradford W. Mott, Stephen Anthony
 // and the Stella Team
 //
 // See the file "License.txt" for information on usage and redistribution of
 // this file, and for a DISCLAIMER OF ALL WARRANTIES.
 //
-// $Id: EventJoyHandler.cxx 3131 2015-01-01 03:49:32Z stephena $
+// $Id: EventJoyHandler.cxx 3239 2015-12-29 19:22:46Z stephena $
 //============================================================================
 
 #include <sstream>
@@ -137,31 +137,31 @@ bool EventHandler::StellaJoystick::setMap(const string& mapString)
 
   // Parse axis/button/hat values
   getValues(items[1], map);
-  if((int)map.size() == numAxes * 2 * kNumModes)
+  if(int(map.size()) == numAxes * 2 * kNumModes)
   {
     // Fill the axes table with events
     auto event = map.begin();
     for(int m = 0; m < kNumModes; ++m)
       for(int a = 0; a < numAxes; ++a)
         for(int k = 0; k < 2; ++k)
-          axisTable[a][k][m] = (Event::Type) *event++;
+          axisTable[a][k][m] = Event::Type(*event++);
   }
   getValues(items[2], map);
-  if((int)map.size() == numButtons * kNumModes)
+  if(int(map.size()) == numButtons * kNumModes)
   {
     auto event = map.begin();
     for(int m = 0; m < kNumModes; ++m)
       for(int b = 0; b < numButtons; ++b)
-        btnTable[b][m] = (Event::Type) *event++;
+        btnTable[b][m] = Event::Type(*event++);
   }
   getValues(items[3], map);
-  if((int)map.size() == numHats * 4 * kNumModes)
+  if(int(map.size()) == numHats * 4 * kNumModes)
   {
     auto event = map.begin();
     for(int m = 0; m < kNumModes; ++m)
       for(int h = 0; h < numHats; ++h)
         for(int k = 0; k < 4; ++k)
-          hatTable[h][k][m] = (Event::Type) *event++;
+          hatTable[h][k][m] = Event::Type(*event++);
   }
 
   return true;
