@@ -8,13 +8,13 @@
 //  SS  SS   tt   ee      ll   ll  aa  aa
 //   SSSS     ttt  eeeee llll llll  aaaaa
 //
-// Copyright (c) 1995-2015 by Bradford W. Mott, Stephen Anthony
+// Copyright (c) 1995-2016 by Bradford W. Mott, Stephen Anthony
 // and the Stella Team
 //
 // See the file "License.txt" for information on usage and redistribution of
 // this file, and for a DISCLAIMER OF ALL WARRANTIES.
 //
-// $Id: FrameBuffer.cxx 3148 2015-03-15 17:36:46Z stephena $
+// $Id: FrameBuffer.cxx 3240 2015-12-29 21:28:10Z stephena $
 //============================================================================
 
 #include <algorithm>
@@ -49,17 +49,13 @@
 FrameBuffer::FrameBuffer(OSystem& osystem)
   : myOSystem(osystem),
     myInitializedCount(0),
-    myPausedCount(0)
+    myPausedCount(0),
+    myCurrentModeList(nullptr)
 {
   myMsg.surface = myStatsMsg.surface = nullptr;
   myMsg.enabled = myStatsMsg.enabled = false;
 }
 
-// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-FrameBuffer::~FrameBuffer()
-{
-}
-
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 bool FrameBuffer::initialize()
 {
@@ -76,8 +72,8 @@ bool FrameBuffer::initialize()
     query_h = s.h;
   }
   // Various parts of the codebase assume a minimum screen size
-  myDesktopSize.w = BSPF_max(query_w, (uInt32)kFBMinW);
-  myDesktopSize.h = BSPF_max(query_h, (uInt32)kFBMinH);
+  myDesktopSize.w = BSPF_max(query_w, uInt32(kFBMinW));
+  myDesktopSize.h = BSPF_max(query_h, uInt32(kFBMinH));
 
   ////////////////////////////////////////////////////////////////////
   // Create fonts to draw text
@@ -121,7 +117,7 @@ bool FrameBuffer::initialize()
     myLauncherFont = make_ptr<GUI::Font>(GUI::stellaDesc);
 
   // Determine possible TIA windowed zoom levels
-  uInt32 maxZoom = maxWindowSizeForScreen((uInt32)kTIAMinW, (uInt32)kTIAMinH,
+  uInt32 maxZoom = maxWindowSizeForScreen(uInt32(kTIAMinW), uInt32(kTIAMinH),
                      myDesktopSize.w, myDesktopSize.h);
 
   // Figure our the smallest zoom level we can use
@@ -194,7 +190,7 @@ FBInitStatus FrameBuffer::createDisplay(const string& title,
   // Initialize video subsystem (make sure we get a valid mode)
   string pre_about = about();
   const VideoMode& mode = getSavedVidMode(useFullscreen);
-  if(width <= (uInt32)mode.screen.w && height <= (uInt32)mode.screen.h)
+  if(width <= mode.screen.w && height <= mode.screen.h)
   {
     if(setVideoMode(myScreenTitle, mode))
     {
@@ -232,7 +228,7 @@ FBInitStatus FrameBuffer::createDisplay(const string& title,
     myStatsMsg.surface = allocateSurface(myStatsMsg.w, myStatsMsg.h);
 
   if(!myMsg.surface)
-    myMsg.surface = allocateSurface((uInt32)kFBMinW, font().getFontHeight()+10);
+    myMsg.surface = allocateSurface(kFBMinW, font().getFontHeight()+10);
 
   // Print initial usage message, but only print it later if the status has changed
   if(myInitializedCount == 1)
@@ -272,7 +268,7 @@ void FrameBuffer::update()
         myOSystem.console().fry();
 
       // And update the screen
-      drawTIA();
+      myTIASurface->render();
 
       // Show frame statistics
       if(myStatsMsg.enabled)
@@ -296,7 +292,7 @@ void FrameBuffer::update()
 
     case EventHandler::S_PAUSE:
     {
-      drawTIA();
+      myTIASurface->render();
 
       // Show a pause message every 5 seconds
       if(myPausedCount++ >= 7*myOSystem.frameRate())
@@ -309,14 +305,14 @@ void FrameBuffer::update()
 
     case EventHandler::S_MENU:
     {
-      drawTIA();
+      myTIASurface->render();
       myOSystem.menu().draw(true);
       break;  // S_MENU
     }
 
     case EventHandler::S_CMDMENU:
     {
-      drawTIA();
+      myTIASurface->render();
       myOSystem.commandMenu().draw(true);
       break;  // S_CMDMENU
     }
@@ -470,12 +466,6 @@ inline void FrameBuffer::drawMessage()
     myMsg.enabled = false;
 }
 
-// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-inline void FrameBuffer::drawTIA()
-{
-  myTIASurface->render();
-}
-
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 shared_ptr<FBSurface> FrameBuffer::allocateSurface(int w, int h, const uInt32* data)
 {
@@ -530,7 +520,7 @@ void FrameBuffer::stateChanged(EventHandler::State state)
 void FrameBuffer::setFullscreen(bool enable)
 {
   const VideoMode& mode = getSavedVidMode(enable);
-  if(setVideoMode(myScreenTitle, mode, true))
+  if(setVideoMode(myScreenTitle, mode))
   {
     myImageRect = mode.image;
     myScreenSize = mode.screen;
@@ -593,12 +583,19 @@ bool FrameBuffer::changeWindowedVidMode(int direction)
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void FrameBuffer::setCursorState()
 {
-  // Always grab mouse in emulation (if enabled),
-  // and don't show the cursor during emulation (if enabled)
+  // Always grab mouse in emulation (if enabled)
   bool emulation =
       myOSystem.eventHandler().state() == EventHandler::S_EMULATE;
   grabMouse(emulation && myOSystem.settings().getBool("grabmouse"));
-  showCursor(!(emulation || myOSystem.settings().getBool("hidecursor")));
+
+  // Show/hide cursor in UI/emulation mode based on 'cursor' setting
+  switch(myOSystem.settings().getInt("cursor"))
+  {
+    case 0: showCursor(false);      break;
+    case 1: showCursor(emulation);  break;
+    case 2: showCursor(!emulation); break;
+    case 3: showCursor(true);       break;
+  }
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -746,8 +743,8 @@ VideoMode::VideoMode(uInt32 iw, uInt32 ih, uInt32 sw, uInt32 sh,
     zoom(z),
     description(desc)
 {
-  sw = BSPF_max(sw, (uInt32)FrameBuffer::kTIAMinW);
-  sh = BSPF_max(sh, (uInt32)FrameBuffer::kTIAMinH);
+  sw = BSPF_max(sw, uInt32(FrameBuffer::kTIAMinW));
+  sh = BSPF_max(sh, uInt32(FrameBuffer::kTIAMinH));
   iw = BSPF_min(iw, sw);
   ih = BSPF_min(ih, sh);
   int ix = (sw - iw) >> 1;
@@ -760,7 +757,7 @@ VideoMode::VideoMode(uInt32 iw, uInt32 ih, uInt32 sw, uInt32 sh,
 void VideoMode::applyAspectCorrection(uInt32 aspect, bool stretch)
 {
   // Width is modified by aspect ratio; other factors may be applied below
-  uInt32 iw = (uInt32)(float(image.width() * aspect) / 100.0);
+  uInt32 iw = uInt32(float(image.width() * aspect) / 100.0);
   uInt32 ih = image.height();
 
   if(fsIndex != -1)
@@ -793,8 +790,8 @@ void VideoMode::applyAspectCorrection(uInt32 aspect, bool stretch)
         stretchFactor = float(int(screen.h / bh) * bh) / ih;
       }
     }
-    iw = (uInt32) (stretchFactor * iw);
-    ih = (uInt32) (stretchFactor * ih);
+    iw = uInt32(stretchFactor * iw);
+    ih = uInt32(stretchFactor * ih);
   }
   else
   {
@@ -804,8 +801,8 @@ void VideoMode::applyAspectCorrection(uInt32 aspect, bool stretch)
   }
 
   // Now re-calculate the dimensions
-  iw = BSPF_min(iw, (uInt32)screen.w);
-  ih = BSPF_min(ih, (uInt32)screen.h);
+  iw = BSPF_min(iw, screen.w);
+  ih = BSPF_min(ih, screen.h);
 
   image.moveTo((screen.w - iw) >> 1, (screen.h - ih) >> 1);
   image.setWidth(iw);
@@ -849,14 +846,14 @@ bool FrameBuffer::VideoModeList::empty() const
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 uInt32 FrameBuffer::VideoModeList::size() const
 {
-  return (uInt32)myModeList.size();
+  return uInt32(myModeList.size());
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void FrameBuffer::VideoModeList::previous()
 {
   --myIdx;
-  if(myIdx < 0) myIdx = (int)myModeList.size() - 1;
+  if(myIdx < 0) myIdx = int(myModeList.size()) - 1;
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
