@@ -8,13 +8,13 @@
 //  SS  SS   tt   ee      ll   ll  aa  aa
 //   SSSS     ttt  eeeee llll llll  aaaaa
 //
-// Copyright (c) 1995-2015 by Bradford W. Mott, Stephen Anthony
+// Copyright (c) 1995-2016 by Bradford W. Mott, Stephen Anthony
 // and the Stella Team
 //
 // See the file "License.txt" for information on usage and redistribution of
 // this file, and for a DISCLAIMER OF ALL WARRANTIES.
 //
-// $Id: VideoDialog.cxx 3131 2015-01-01 03:49:32Z stephena $
+// $Id: VideoDialog.cxx 3243 2015-12-29 23:45:21Z stephena $
 //============================================================================
 
 #include <sstream>
@@ -302,11 +302,6 @@ VideoDialog::VideoDialog(OSystem& osystem, DialogContainer& parent,
 #endif
 }
 
-// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-VideoDialog::~VideoDialog()
-{
-}
-
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void VideoDialog::loadConfig()
 {
@@ -370,7 +365,7 @@ void VideoDialog::loadConfig()
   myTVMode->setSelected(
     instance().settings().getString("tv.filter"), "0");
   int preset = instance().settings().getInt("tv.filter");
-  handleTVModeChange((NTSCFilter::Preset)preset);
+  handleTVModeChange(NTSCFilter::Preset(preset));
 
   // TV Custom adjustables
   loadTVAdjustables(NTSCFilter::PRESET_CUSTOM);
@@ -562,7 +557,7 @@ void VideoDialog::loadTVAdjustables(NTSCFilter::Preset preset)
 {
   NTSCFilter::Adjustable adj;
   instance().frameBuffer().tiaSurface().ntsc().getAdjustables(
-      adj, (NTSCFilter::Preset)preset);
+      adj, NTSCFilter::Preset(preset));
   myTVSharp->setValue(adj.sharpness);
   myTVSharpLabel->setValue(adj.sharpness);
   myTVHue->setValue(adj.hue);
@@ -616,8 +611,8 @@ void VideoDialog::handleCommand(CommandSender* sender, int cmd,
       break;
 
     case kTVModeChanged:
-      handleTVModeChange((NTSCFilter::Preset)myTVMode->getSelectedTag().toInt());
-
+      handleTVModeChange(NTSCFilter::Preset(myTVMode->getSelectedTag().toInt()));
+      break;
     case kTVSharpChanged:  myTVSharpLabel->setValue(myTVSharp->getValue());
       break;
     case kTVHueChanged:  myTVHueLabel->setValue(myTVHue->getValue());
